.. image:: https://img.shields.io/pypi/v/jaraco.crypto.svg
   :target: https://pypi.org/project/jaraco.crypto

.. image:: https://img.shields.io/pypi/pyversions/jaraco.crypto.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.crypto/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.crypto

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/jaraco.crypto/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/jaraco.crypto/branch/master

.. .. image:: https://readthedocs.org/projects/jaracocrypto/badge/?version=latest
..    :target: https://jaracocrypto.readthedocs.io/en/latest/?badge=latest

A set of cryptographic routines and utilities
implemented in pure Python.

================
Acknowledgements
================

Many of the ideas and much of the code has been adapted from or inspired by
several other projects, including::

 - The code repository was originally a fork of the `ctypescrypto project
   <http://code.google.com/p/ctypescrypto/>`_. The code history includes the
   full history of the ancestral project.
 - The blowfish code was adapted from a module contributed to the community
   by Michael Gilfix.
